## 交易日历

接口：trade_cal

描述：获取各大期货交易所交易日历数据

积分：需2000积分才可以提取数据

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| exchange | str | N | 交易所 SHFE 上期所 DCE 大商所 CFFEX中金所  CZCE郑商所 INE上海国际能源交易所 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| is_open | int | N | 是否交易 0休市 1交易 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| exchange | str | Y | 交易所 同参数部分描述 |
| cal_date | str | Y | 日历日期 |
| is_open | int | Y | 是否交易 0休市 1交易 |
| pretrade_date | str | N | 上一个交易日 |

接口示例

```python
pro = ts.pro_api('your token')


df = pro.trade_cal(exchange='DCE', start_date='20180101', end_date='20181231')
```

或者

```python
df = pro.query('trade_cal', exchange='DCE', start_date='20180101', end_date='20181231')
```

数据样例

```python
exchange  cal_date  is_open
0        DCE  20180101        0
```